@@ -37,4 +37,7 @@ mod float_impl;
 pub use float_impl::*;
 
 mod fixed_impl;
-pub use fixed_impl::*;
\ No newline at end of file
+pub use fixed_impl::*;
+
+mod int_impl;
+pub use int_impl::*;
\ No newline at end of file
